AnuvadakManager class
- Mixed-in types
Constructors
- AnuvadakManager.getInstance()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
initialize(
String ID) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
parseJsonV1Sync(
String jsonString) → Future< void> -
printLongString(
String text) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setAnuvadakCallBack(
Anuvadakcallback callback) → Future< void> -
setCallback(
{OnUpdateSuccess? onUpdateSuccess, OnError? onError, OnUpdateWithError? onUpdateWithError}) → void -
toString(
) → String -
A string representation of this object.
inherited
-
translate(
String key) → String - Get localized string
-
updateLocale(
String locale) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited